/**************************************************************
* TABLES 3 AND 5: 
	Generates and exports Wald results for Tables 3 and 5.
	Section A runs analysis; Section B exports results.
**************************************************************/

clear
set more off
set mem 400m
set matsize 800

capture log close
*log using 150717ftestslog.log, replace 

local outfiletests 	= "150720growthresults"
capture erase ../Data/`outfiletests'.dta

***************************************************************
* A. Run Regressions
***************************************************************
foreach shift of numlist 0 1 2 5 6 { //shifts in timing
	/*Note: Shift=0 corresponds to row 1 of tables (treatment timing t), 
			Shift=1 corresponds to row 2 of tables (treatment timing t+1), etc. 
			Shifts 0-2 are treatment timings; shifts 5-6 are control timings. */

	u ../Data/LeaderAndPWTfinal, clear

	** Run Regression
	local regressionEQ = "_Iyear* _Icountry* s`shift'_Preid* s`shift'_Postid*"

	qui reg growth `regressionEQ'

	local regN = e(N)
	local regK = e(N) - e(df_r)
	display "N: `regN'"
	display "K: `regK'"
			
	** Generate Errors
	predict temperrors, r
	g allsample = 1
			
	** Estimate heterosked.--assume mean 0
	g tempsquaree = temperrors^2
	bys regionNum: egen tempsumerrors = sum(tempsquaree)
	bys regionNum: egen tempdenom = count(tempsquaree)
	qui tab regionNum
	local numGroups = r(r) 

	g tempsigsquare = tempsumerrors / (tempdenom) 
	bys regionNum: summ tempsigsquare 

	** Generate autocorrelation
	tsset countryID year
	g tempeprimee = temperrors * l.temperrors / tempsigsquare
	bys regionNum: egen tempsumcorr = sum(tempeprimee)
	bys regionNum: egen tempdenomcorr = count(tempeprimee)
	qui tab regionNum
	local numGroups = r(r) 
	g tempro = tempsumcorr / (tempdenomcorr ) 		
	bys regionNum: summ tempro 

	** Generate the new variance-covariance matrix
	sort countryID year
	by countryID: g temprowvar = _n

	** For each country, we need to generate the within country matrix
	summ countryID
	local numCountries = r(max)
	local maxYears = 60
	g str10 tempMatrixName = ""

	foreach Z of  num 1/`numCountries' {
		qui replace tempMatrixName = "W`Z'" if countryID == `Z'
		/*For each country, generate the appropriate matrix*/
		matrix W`Z' = I(`maxYears')
		qui summ tempsigsquare if countryID == `Z'
		local thissigsquare = r(mean)
		
		qui summ tempro if countryID == `Z'
		local thisro = r(mean)
				
		foreach X of num 1/`maxYears' {
			foreach Y of num 1/`maxYears' {
				
				matrix W`Z'[`X',`Y'] = 	(`thisro')^(abs(`X' - `Y'))		
			}	
		}
		matrix W`Z' = W`Z' * `thissigsquare'
	}

	matrix accum XPX = `regressionEQ' if e(sample)
	matrix glsaccum XPOX = `regressionEQ' if e(sample), group(countryID) glsmat(tempMatrixName) row(temprowvar)
	matrix newV = syminv(XPX) * XPOX * syminv(XPX)

	** Repost new results
	matrix tempResults = e(b)
	g tempSample = e(sample)
	local depvar = e(depvar)
	local obs = e(N)
	eret post tempResults newV, dep(growth) o(`obs') esample(tempSample)

	disp "Regression with Corrected Standard errors"
	eret disp
	drop temp*
				
	** Create Marker:  Need to skip test on coefficents not included in regression 
	g TESTvar = 0
	qui foreach num of numlist 1/75 {
		capture replace TESTvar = 1 if _se[s`shift'_Postid`num']!=. & _se[s`shift'_Preid`num']!=. in `num' 
		capture replace TESTvar = 0 if _se[s`shift'_Postid`num']==0 | _se[s`shift'_Preid`num']==0 in `num' 
	}

	** Stats we want
	g Chi2 = .
	g PVal = .
	g NumLead = .
	g J = .

	** Now test collective significance or Pre vs. Post for each leader, by subset
	foreach LeaderSet of numlist 1/4 { //subsamples of leader type (all, >=2 yrs tenure, autocrat, democrat)
		local FIRST=0
		foreach num of numlist 1/75 {
			qui count if TRUE`LeaderSet'==1 & id`num'==1
			if r(N)>0 {
				if TESTvar[`num']!=1 {
					continue
				}
				if `FIRST'==1 {
					qui test s`shift'_Preid`num'==s`shift'_Postid`num', accumulate notest
				}
				if `FIRST'==0 {
					local FIRST = 1
					qui test s`shift'_Preid`num'==s`shift'_Postid`num'
				}
			}	
		}
		test
		
		** Store results of F-test
		replace Chi2 = r(chi2) in `LeaderSet'
		replace NumLead = r(df) in `LeaderSet'
		replace PVal = r(p) in `LeaderSet'
		replace J = Chi2 / NumLead in `LeaderSet'
		
	} //closes leader subsample loop

	** Save results of F-tests
	g Shift = `shift'
	g TrueVal = _n
	keep if TrueVal <= 4
	keep Chi2 NumLead PVal TrueVal Shift J
	capture confirm file ../Data/`outfiletests'.dta
	display _rc
	if _rc != 0 {
		save ../Data/`outfiletests', replace
		display "Replaced!"
	}
	else {
		append using ../Data/`outfiletests'	
		save ../Data/`outfiletests', replace
		display "Appended!"
	}
	
} //closes shifts in timing loop

**************************************************************
* B. Export Results/Make Tables
**************************************************************

** Get Data
use ../Data/`outfiletests', clear

set obs `=_N + 4'
local rowNum 	= 1
local numVars 	= 2
local numvars1 	= `numVars' + 1

** Create outvars for exporting results
qui for num 0/3: qui g tempOutVarX = ""

** Column names
qui replace  tempOutVar`numVars' 	= "J" in 1
qui replace  tempOutVar`numvars1' 	= "p-val" in 1						
qui replace  tempOutVar1 			= "Num Lead" in 1										

** Loop over leader subsamples
foreach TRUE of num 1/4 {
	if `TRUE' == 1 {
		qui replace  tempOutVar0 = "All" in `rowNum'
	}
	if `TRUE' == 2 {
		qui replace  tempOutVar0 = "Tenure >= 2 Years" in `rowNum'
	}					
	if `TRUE' == 3 {
		qui replace  tempOutVar0 = "Autocrats (Polity)" in `rowNum'
	}
	if `TRUE' == 4 {
		qui replace  tempOutVar0 = "Democrats (Polity)" in `rowNum'
	}

	** Loop over timing shifts
	foreach X of num 0 1 2 5 6 {
		local ++rowNum
		
		** J-statistic
		qui summ J if TrueVal == `TRUE' & Shift == `X'
		assert r(N) <= 1
		qui replace  tempOutVar`numVars' = string(r(mean),"%5.3f") in `rowNum'
		
		** P-value (Wald)
		qui summ PVal if TrueVal == `TRUE' & Shift == `X'
		assert r(N) <= 1
		local numvars1 = `numVars' + 1
		qui replace  tempOutVar`numvars1' = string(r(mean),"%6.4f") in `rowNum'
		qui replace  tempOutVar0 = "`X'" in `rowNum'
		
		** Number of leaders in sample
		qui summ NumLead if TrueVal == `TRUE' & Shift == `X'		
		qui replace tempOutVar1 = string(r(mean)) in `rowNum'
	} //closes timing shifts loop	
	local ++rowNum
} //closes leader subsample loop

** Write output file
capture erase ../Output/tables3_5.csv
outsheet tempOutVar* using ../Output/tables3_5.csv, non comma

capture log close                                  
